@@ -365,7 +365,7 @@ class Bot:
             sendable = self.sendable,
             _copy = True,
             _cookie = self._cookie,
-            human = self.human
+            human = self.human,
             queue = self.queue)
         copy.set_handlers(self.handlers)
         copy.set_regexes(self._regexes)
